/// <reference types="node" />
import { SpawnOptions } from 'child_process';
import { Answers } from 'inquirer';
import { PlopGeneratorConfig } from 'node-plop';
export interface PlopActionHooksFailures {
    type: string;
    path: string;
    error: string;
    message: string;
}
export interface PlopActionHooksChanges {
    type: string;
    path: string;
}
export interface PlopActionHooks {
    onComment?: (msg: string) => void;
    onSuccess?: (change: PlopActionHooksChanges) => void;
    onFailure?: (failure: PlopActionHooksFailures) => void;
}
export interface GeneratorActionsOutcome {
    changes: PlopActionHooksChanges[];
    failures: PlopActionHooksFailures[];
}
export interface PlopGeneratorRunner {
    runGeneratorPrompts: (generator: PlopGeneratorConfig, bypassArr?: string[], prevAns?: Answers) => Promise<any>;
    runGeneratorActions: (generator: PlopGeneratorConfig, data: any, hooks?: PlopActionHooks) => Promise<GeneratorActionsOutcome>;
}
/**
 * TS entitlements bits will likely move to foundation-data.
 * This data now comes from https://genesisglobal.jfrog.io/ui/api/v1/download/contentBrowsing/seed-area
 */
export declare enum Entitlement {
    workspaceCreate = "Workspace_Create",
    workspaceConfigure = "Workspace_Configure",
    workspaceDelete = "Workspace_Delete",
    workspaceList = "Workspace_List",
    appCreate = "App_Create",
    appConfigure = "App_Configure",
    appDelete = "App_Delete",
    appList = "App_List",
    foundationSync = "Foundation_Sync",
    foundationSchemaCreate = "Foundation_Schema_Create",
    foundationComponentCreate = "Foundation_Component_Create",
    designSystemCreate = "Design_System_Create"
}
export type BinCmdKey = 'genx' | 'foundation-cli';
export type TokenType = 'Bearer' | 'Basic';
export type SeedListType = 'apps' | 'workspaces';
export type ContentType = 'application/octet-stream' | 'application/json' | 'application/x-www-form-urlencoded';
export interface RunConfig {
    external: boolean;
    binCmdKey: BinCmdKey;
}
export interface HelpConfig {
    binCmdKey: BinCmdKey;
}
export declare const DslTag = "DSL";
export declare const dslName = "GPALX";
export declare const GENX_DIR = ".genx";
export declare const appCommand = "app";
export interface ShellOptions {
    readonly command: string;
    /**
     * @default - project dir
     */
    readonly cwd?: string;
    readonly label?: string;
    readonly logprefix?: string;
    readonly spawnOptions?: SpawnOptions;
    /** @default false */
    readonly quiet?: boolean;
}
/**
 * A single step within a task. The step could either be  the execution of a
 * shell command or execution of a sub-task, by name.
 */
export interface TaskStep {
    /**
     * Step name
     *
     * @default - no name
     */
    readonly name?: string;
    /**
     * The working directory for this step.
     *
     * @default - determined by the task
     */
    readonly cwd?: string;
    /**
     * Shell command to execute
     *
     * @default - don't execute a shell command
     */
    readonly exec?: string;
    /**
     * Subtask to execute
     *
     * @default - don't spawn a subtask
     */
    readonly spawn?: string;
    /**
     * Print a message.
     * @default - don't say anything
     */
    readonly say?: string;
    /**
     * The name of a built-in task to execute.
     *
     * Built-in tasks are Node.js programs provided by the CLI
     *
     * The name is a path relative to the tasks/ directory (without the .task.js extension).
     * For example, if your built in builtin task is under `src/tasks/resolve-version.task.ts`,
     * then this would be `release/resolve-version`.
     *
     * @default - do not execute a builtin task
     */
    readonly builtin?: string;
}
/**
 * Specification of a single task.
 */
export interface TaskSpec {
    /**
     * Task name.
     */
    readonly name: string;
    /**
     * Task steps.
     */
    readonly steps?: TaskStep[];
    /**
     * The description of this build command.
     * @default - the task name
     */
    readonly description?: string;
    /**
     * Defines environment variables for the execution of this task.
     * Values in this map will be evaluated in a shell, so you can do stuff like `$(echo "foo")`.
     * @default {}
     */
    readonly env?: {
        [name: string]: string;
    };
    /**
     * A set of environment variables that must be defined in order to execute
     * this task. Task execution will fail if one of these is not defined.
     */
    readonly requiredEnv?: string[];
    /**
     * A shell command which determines if the this task should be executed. If
     * the program exits with a zero exit code, steps will be executed. A non-zero
     * code means that task will be skipped.
     */
    readonly condition?: string;
    /**
     * The working directory for all steps in this task (unless overridden by the
     * step).
     *
     * @default - process.cwd()
     */
    readonly cwd?: string;
}
/**
 * Schema for `tasks.json`.
 */
export interface TasksManifest {
    /**
     * All tasks available for this project.
     */
    readonly tasks?: {
        [name: string]: TaskSpec;
    };
    /**
     * Environment for all tasks.
     */
    readonly env?: {
        [name: string]: string;
    };
}
//# sourceMappingURL=types.d.ts.map